.. _recipe_asr.dimensionality:

asr.dimensionality
==================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.dimensionality`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.dimensionality.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.dimensionality

or as a python module

.. code-block:: console

   $ python -m asr.dimensionality


Steps
-----


asr.dimensionality
^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.dimensionality.main
   